<?php
/**
 * Amount Left for Free Shipping for WooCommerce - Functions
 *
 * @version 1.4.5
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! function_exists( 'alg_wc_alfs_is_equal' ) ) {
	/**
	 * alg_wc_alfs_is_equal.
	 *
	 * @version 1.4.2
	 * @since   1.4.2
	 * @todo    [dev] (maybe) better epsilon value
	 */
	function alg_wc_alfs_is_equal( $float1, $float2 ) {
		$epsilon = ( defined( 'PHP_FLOAT_EPSILON' ) ? PHP_FLOAT_EPSILON : 0.000000001 );
		return ( abs( $float1 - $float2 ) < $epsilon );
	}
}

if ( ! function_exists( 'alg_get_left_to_free_shipping' ) ) {
	/*
	 * alg_get_left_to_free_shipping.
	 *
	 * @version 1.4.2
	 * @since   1.0.0
	 * @return  string
	 */
	function alg_get_left_to_free_shipping( $content, $multiply_by = 1 ) {
		if ( 0 != ( $min_free_shipping_amount = alg_wc_alfs_get_min_free_shipping_amount() ) ) {
			$total = alg_wc_alfs_get_cart_total();
			if ( $total > $min_free_shipping_amount || alg_wc_alfs_is_equal( $total, $min_free_shipping_amount ) ) {
				return do_shortcode( get_option( 'alg_wc_left_to_free_shipping_info_content_reached',
					__( 'You have free delivery!', 'amount-left-free-shipping-woocommerce' ) ) );
			} else {
				$amount_left_for_free_shipping = ( $min_free_shipping_amount - $total ) * $multiply_by;
				$free_shipping_min_amount      = ( $min_free_shipping_amount )          * $multiply_by;
				$current_cart_total            = ( $total )                             * $multiply_by;
				$placeholders = array(
					'%amount_left_for_free_shipping%'     => wc_price( $amount_left_for_free_shipping ),
					'%free_shipping_min_amount%'          => wc_price( $free_shipping_min_amount ),
					'%current_cart_total%'                => wc_price( $current_cart_total ),
					'%amount_left_for_free_shipping_raw%' => $amount_left_for_free_shipping,
					'%free_shipping_min_amount_raw%'      => $free_shipping_min_amount,
					'%current_cart_total_raw%'            => $current_cart_total,
				);
				if ( '' == $content ) {
					$content = sprintf( __( '%s left for free shipping', 'amount-left-free-shipping-woocommerce' ), '%amount_left_for_free_shipping%' );
				}
				return str_replace( array_keys( $placeholders ), $placeholders, $content );
			}
		}
	}
}

if ( ! function_exists( 'alg_wc_alfs_get_min_free_shipping_amount' ) ) {
	/*
	 * alg_wc_alfs_get_min_free_shipping_amount.
	 *
	 * @version 1.4.5
	 * @since   1.4.0
	 */
	function alg_wc_alfs_get_min_free_shipping_amount() {
		$min_amount_user_roles = get_option( 'alg_wc_left_to_free_shipping_mma_roles', array() );
		if ( ! empty( $min_amount_user_roles ) ) {
			$values     = get_option( 'alg_wc_left_to_free_shipping_mma_roles_val', array() );
			$user       = ( function_exists( 'wp_get_current_user' ) ? wp_get_current_user() : false );
			$user_roles = ( ! empty( $user->roles ) ? $user->roles : array( 'guest' ) );
			foreach ( $user_roles as $user_role ) {
				if ( '' == $user_role ) {
					$user_role = 'guest';
				}
				if ( in_array( $user_role, $min_amount_user_roles ) && ! empty( $values[ $user_role ] ) ) {
					return $values[ $user_role ];
				}
			}
		}
		if ( 0 != ( $manual_min_amount = get_option( 'alg_wc_left_to_free_shipping_manual_min_amount', 0 ) ) ) {
			return $manual_min_amount;
		}
		$min_free_shipping_amount = 0;
		$current_wc_version       = get_option( 'woocommerce_version', null );
		if ( version_compare( $current_wc_version, '2.6.0', '<' ) ) {
			$free_shipping = new WC_Shipping_Free_Shipping();
			if ( in_array( $free_shipping->requires, array( 'min_amount', 'either', 'both' ) ) ) {
				$min_free_shipping_amount = $free_shipping->min_amount;
			}
		} else {
			$legacy_free_shipping = new WC_Shipping_Legacy_Free_Shipping();
			if ( 'yes' === $legacy_free_shipping->enabled ) {
				if ( in_array( $legacy_free_shipping->requires, array( 'min_amount', 'either', 'both' ) ) ) {
					$min_free_shipping_amount = $legacy_free_shipping->min_amount;
				}
			}
			if ( 0 == $min_free_shipping_amount ) {
				if ( function_exists( 'WC' ) && ( $wc_shipping = WC()->shipping ) && ( $wc_cart = WC()->cart ) ) {
					if ( $wc_shipping->enabled ) {
						if ( $packages = $wc_cart->get_shipping_packages() ) {
							$shipping_methods = $wc_shipping->load_shipping_methods( $packages[0] );
							foreach ( $shipping_methods as $shipping_method ) {
								if ( 'yes' === $shipping_method->enabled && 0 != $shipping_method->instance_id ) {
									if ( 'WC_Shipping_Free_Shipping' === get_class( $shipping_method ) ) {
										if ( in_array( $shipping_method->requires, array( 'min_amount', 'either', 'both' ) ) ) {
											$min_free_shipping_amount = $shipping_method->min_amount;
											break;
										}
									}
								}
							}
						}
					}
				}
			}
		}
		return $min_free_shipping_amount;
	}
}

if ( ! function_exists( 'alg_wc_alfs_get_cart_total' ) ) {
	/*
	 * alg_wc_alfs_get_cart_total.
	 *
	 * @version 1.4.4
	 * @since   1.4.0
	 * @see     `WC_Shipping_Free_Shipping::is_available()` (/woocommerce/includes/shipping/free-shipping/class-wc-shipping-free-shipping.php)
	 */
	function alg_wc_alfs_get_cart_total() {
		if ( ! function_exists( 'WC' ) || ! isset( WC()->cart ) ) {
			return 0;
		}
		$total = WC()->cart->get_displayed_subtotal();
		if ( 'yes' === get_option( 'alg_wc_left_to_free_shipping_include_discounts', 'yes' ) ) {
			if ( WC()->cart->display_prices_including_tax() ) {
				$total = round( $total - ( WC()->cart->get_discount_total() + WC()->cart->get_discount_tax() ), wc_get_price_decimals() );
			} else {
				$total = round( $total - WC()->cart->get_discount_total(), wc_get_price_decimals() );
			}
		}
		return $total;
	}
}

if ( ! function_exists( 'alg_wc_get_left_to_free_shipping' ) ) {
	/*
	 * alg_wc_get_left_to_free_shipping.
	 *
	 * @version 1.3.0
	 * @since   1.3.0
	 */
	function alg_wc_get_left_to_free_shipping( $content, $multiply_by = 1 ) {
		return alg_get_left_to_free_shipping( $content, $multiply_by );
	}
}

if ( ! function_exists( 'alg_get_left_to_free_shipping_shortcode_function' ) ) {
	/*
	 * alg_get_left_to_free_shipping_shortcode_function.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function alg_get_left_to_free_shipping_shortcode_function( $atts, $content ) {
		$atts = shortcode_atts( array( 'content' => '', 'multiply_by' => 1 ), $atts, 'alg_get_left_to_free_shipping' );
		return alg_get_left_to_free_shipping( $atts['content'], $atts['multiply_by'] );
	}
}
add_shortcode( 'alg_get_left_to_free_shipping', 'alg_get_left_to_free_shipping_shortcode_function' );
add_shortcode( 'alg_wc_left_to_free_shipping',  'alg_get_left_to_free_shipping_shortcode_function' );

if ( ! function_exists( 'alg_wc_alfs_translate_function' ) ) {
	/**
	 * alg_wc_alfs_translate_function.
	 *
	 * @version 1.3.0
	 * @since   1.3.0
	 */
	function alg_wc_alfs_translate_function( $atts, $content = '' ) {
		// E.g.: `[alg_wc_left_to_free_shipping_translate lang="DE" lang_text="%amount_left_for_free_shipping% für kostenlosen Versand" not_lang_text="%amount_left_for_free_shipping% left for free shipping"]`
		if ( isset( $atts['lang_text'] ) && isset( $atts['not_lang_text'] ) && ! empty( $atts['lang'] ) ) {
			return ( ! defined( 'ICL_LANGUAGE_CODE' ) || ! in_array( strtolower( ICL_LANGUAGE_CODE ), array_map( 'trim', explode( ',', strtolower( $atts['lang'] ) ) ) ) ) ?
				$atts['not_lang_text'] : $atts['lang_text'];
		}
		// E.g.: `[alg_wc_left_to_free_shipping_translate lang="DE"]%amount_left_for_free_shipping% für kostenlosen Versand[/alg_wc_left_to_free_shipping_translate][alg_wc_left_to_free_shipping_translate not_lang="DE"]%amount_left_for_free_shipping% left for free shipping[/alg_wc_left_to_free_shipping_translate]`
		return (
			( ! empty( $atts['lang'] )     && ( ! defined( 'ICL_LANGUAGE_CODE' ) || ! in_array( strtolower( ICL_LANGUAGE_CODE ), array_map( 'trim', explode( ',', strtolower( $atts['lang'] ) ) ) ) ) ) ||
			( ! empty( $atts['not_lang'] ) &&     defined( 'ICL_LANGUAGE_CODE' ) &&   in_array( strtolower( ICL_LANGUAGE_CODE ), array_map( 'trim', explode( ',', strtolower( $atts['not_lang'] ) ) ) ) )
		) ? '' : $content;
	}
}
add_shortcode( 'alg_wc_left_to_free_shipping_translate', 'alg_wc_alfs_translate_function' );
