<?php
/**
 * Amount Left for Free Shipping for WooCommerce - Core Class
 *
 * @version 1.4.3
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_Left_To_Free_Shipping_Core' ) ) :

class Alg_WC_Left_To_Free_Shipping_Core {

	/**
	 * Constructor.
	 *
	 * @version 1.4.3
	 * @since   1.0.0
	 */
	function __construct() {
		if ( 'yes' === get_option( 'alg_wc_left_to_free_shipping_enabled', 'yes' ) ) {
			if ( 'yes' === get_option( 'alg_wc_left_to_free_shipping_info_enabled_cart', 'no' ) ) {
				add_action(
					get_option( 'alg_wc_left_to_free_shipping_info_position_cart', 'woocommerce_after_cart_totals' ),
					array( $this, 'show_left_to_free_shipping_info_cart' ),
					get_option( 'alg_wc_left_to_free_shipping_info_priority_cart', 10 )
				);
			}
			if ( 'yes' === apply_filters( 'alg_wc_left_to_free_shipping_value_mini_cart', 'no' ) ) {
				add_action(
					get_option( 'alg_wc_left_to_free_shipping_info_position_mini_cart', 'woocommerce_after_mini_cart' ),
					array( $this, 'show_left_to_free_shipping_info_mini_cart' ),
					get_option( 'alg_wc_left_to_free_shipping_info_priority_mini_cart', 10 )
				);
			}
			if ( 'yes' === apply_filters( 'alg_wc_left_to_free_shipping_value_checkout', 'no' ) ) {
				add_action(
					get_option( 'alg_wc_left_to_free_shipping_info_position_checkout', 'woocommerce_checkout_after_order_review' ),
					array( $this, 'show_left_to_free_shipping_info_checkout' ),
					get_option( 'alg_wc_left_to_free_shipping_info_priority_checkout', 10 )
				);
			}
		}
		do_action( 'alg_wc_left_to_free_shipping_core_loaded', $this );
	}

	/**
	 * show_left_to_free_shipping_info_checkout.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 */
	function show_left_to_free_shipping_info_checkout() {
		$this->show_left_to_free_shipping_info( do_shortcode( get_option( 'alg_wc_left_to_free_shipping_info_content_checkout',
			sprintf( __( '%s left for free shipping', 'amount-left-free-shipping-woocommerce' ), '%amount_left_for_free_shipping%' ) ) ) );
	}

	/**
	 * show_left_to_free_shipping_info_mini_cart.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 */
	function show_left_to_free_shipping_info_mini_cart() {
		$this->show_left_to_free_shipping_info( do_shortcode( get_option( 'alg_wc_left_to_free_shipping_info_content_mini_cart',
			sprintf( __( '%s left for free shipping', 'amount-left-free-shipping-woocommerce' ), '%amount_left_for_free_shipping%' ) ) ) );
	}

	/**
	 * show_left_to_free_shipping_info_cart.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 */
	function show_left_to_free_shipping_info_cart() {
		$this->show_left_to_free_shipping_info( do_shortcode( get_option( 'alg_wc_left_to_free_shipping_info_content_cart',
			sprintf( __( '%s left for free shipping', 'amount-left-free-shipping-woocommerce' ), '%amount_left_for_free_shipping%' ) ) ) );
	}

	/**
	 * show_left_to_free_shipping_info.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function show_left_to_free_shipping_info( $content ) {
		echo alg_get_left_to_free_shipping( $content );
	}

}

endif;

return new Alg_WC_Left_To_Free_Shipping_Core();
