<?php
/**
 * Amount Left for Free Shipping for WooCommerce - General Section Settings
 *
 * @version 1.4.5
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_Left_To_Free_Shipping_Settings_General' ) ) :

class Alg_WC_Left_To_Free_Shipping_Settings_General extends Alg_WC_Left_To_Free_Shipping_Settings_Section {

	/**
	 * Constructor.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 */
	function __construct() {
		$this->id   = '';
		$this->desc = __( 'General', 'amount-left-free-shipping-woocommerce' );
		parent::__construct();
	}

	/**
	 * get_user_roles.
	 *
	 * @version 1.4.5
	 * @since   1.4.5
	 */
	function get_user_roles() {
		global $wp_roles;
		$roles = apply_filters( 'editable_roles', ( ( isset( $wp_roles ) && is_object( $wp_roles ) ) ? $wp_roles->roles : array() ) );
		return array_merge( array( 'guest' => __( 'Guest', 'amount-left-free-shipping-woocommerce' ) ), wp_list_pluck( $roles, 'name' ) );
	}

	/**
	 * get_settings.
	 *
	 * @version 1.4.5
	 * @since   1.0.0
	 * @todo    [dev] maybe add to placeholders *info*: "raw" amounts: `%amount_left_for_free_shipping_raw%`, `%free_shipping_min_amount_raw%` and `%current_cart_total_raw%`.
	 * @todo    [dev] "notice" as "position" in cart and checkout
	 * @todo    [feature] multiple positions in cart / checkout / minicart
	 */
	function get_settings() {
		$desc = '<div style="background-color:white;color:black;padding:10px;">' .
			'<p>' . '&#8505;' . ' ' . __( 'Here you can enable info in cart, "add to cart" notice, mini cart and checkout.', 'amount-left-free-shipping-woocommerce' ) . ' ' .
				sprintf( __( 'Values that will be replaced in "Content": %s.', 'amount-left-free-shipping-woocommerce' ),
					'<code>%amount_left_for_free_shipping%</code>, <code>%free_shipping_min_amount%</code>, <code>%current_cart_total%</code>' ) . '</p>' .
			'<p>' . '<strong>' . __( 'Alternatively you can use:', 'amount-left-free-shipping-woocommerce' ) . '</strong>' .
				'<ol>' .
					'<li>' .
							'<span style="text-decoration:underline;">' . __( 'Widget', 'amount-left-free-shipping-woocommerce' ) . '</span>' . ': ' .
							'<em>' . __( 'Amount Left for Free Shipping', 'amount-left-free-shipping-woocommerce' ) . '</em>' .
					'</li>' .
					'<li>' .
							'<span style="text-decoration:underline;">' . __( 'Shortcode', 'amount-left-free-shipping-woocommerce' ) . '</span>' . ': ' .
							'<code>[alg_wc_left_to_free_shipping content="%amount_left_for_free_shipping% left for free shipping"]</code>' .
					'</li>' .
					'<li>' .
							'<span style="text-decoration:underline;">' . __( 'PHP function', 'amount-left-free-shipping-woocommerce' ) . '</span>' . ': ' .
							'<code>alg_wc_get_left_to_free_shipping( "%amount_left_for_free_shipping% left for free shipping" );</code>' .
					'</li>' .
				'</ol>' .
			'</p>' .
		'</div>';
		$this->pro_desc = sprintf( 'You will need <a href="%s" target="_blank">Amount Left for Free Shipping for WooCommerce Pro plugin</a> to enable this option.',
			'https://wpfactory.com/item/amount-left-free-shipping-woocommerce/' );
		$settings = array(
			array(
				'title'    => __( 'Amount Left for Free Shipping Options', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => $desc,
				'type'     => 'title',
				'id'       => 'alg_wc_left_to_free_shipping_options',
			),
			array(
				'title'    => __( 'Amount Left for Free Shipping', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => '<strong>' . __( 'Enable plugin', 'amount-left-free-shipping-woocommerce' ) . '</strong>',
				'id'       => 'alg_wc_left_to_free_shipping_enabled',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_left_to_free_shipping_options',
			),

			array(
				'title'    => __( 'General Options', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_left_to_free_shipping_general_options',
			),
			array(
				'title'    => __( 'Include discounts', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => __( 'Include', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'Include discounts when calculating cart total.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_include_discounts',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_left_to_free_shipping_general_options',
			),

			array(
				'title'    => __( 'Cart Options', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_left_to_free_shipping_cart_options',
			),
			array(
				'title'    => __( 'Enable/Disable', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => __( 'Enable section', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_enabled_cart',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'title'    => __( 'Content', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'You can use HTML and/or shortcodes here.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_content_cart',
				'default'  => sprintf( __( '%s left for free shipping', 'amount-left-free-shipping-woocommerce' ), '%amount_left_for_free_shipping%' ),
				'type'     => 'textarea',
				'css'      => 'width:100%;height:100px;',
				'alg_wc_alfs_raw' => true,
			),
			array(
				'title'    => __( 'Position', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_position_cart',
				'default'  => 'woocommerce_after_cart_totals',
				'type'     => 'select',
				'class'    => 'chosen_select',
				'options'  => array(
					'woocommerce_before_cart'                    => __( 'Before cart', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_before_cart_table'              => __( 'Before cart table', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_before_cart_contents'           => __( 'Before cart contents', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_cart_contents'                  => __( 'Cart contents', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_cart_coupon'                    => __( 'Cart coupon', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_cart_actions'                   => __( 'Cart actions', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_after_cart_contents'            => __( 'After cart contents', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_after_cart_table'               => __( 'After cart table', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_cart_collaterals'               => __( 'Cart collaterals', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_after_cart'                     => __( 'After cart', 'amount-left-free-shipping-woocommerce' ),

					'woocommerce_before_cart_totals'             => __( 'Before cart totals', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_cart_totals_before_shipping'    => __( 'Cart totals: Before shipping', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_cart_totals_after_shipping'     => __( 'Cart totals: After shipping', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_cart_totals_before_order_total' => __( 'Cart totals: Before order total', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_cart_totals_after_order_total'  => __( 'Cart totals: After order total', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_proceed_to_checkout'            => __( 'Proceed to checkout', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_after_cart_totals'              => __( 'After cart totals', 'amount-left-free-shipping-woocommerce' ),

					'woocommerce_before_shipping_calculator'     => __( 'Before shipping calculator', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_after_shipping_calculator'      => __( 'After shipping calculator', 'amount-left-free-shipping-woocommerce' ),

					'woocommerce_cart_is_empty'                  => __( 'If cart is empty', 'amount-left-free-shipping-woocommerce' ),
				),
			),
			array(
				'title'    => __( 'Position order (priority)', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'Here you can move the info inside the Position selected above.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_priority_cart',
				'default'  => 10,
				'type'     => 'number',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_left_to_free_shipping_cart_options',
			),

			array(
				'title'    => __( 'Mini Cart Options', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_left_to_free_shipping_mini_cart_options',
			),
			array(
				'title'    => __( 'Enable/Disable', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => __( 'Enable section', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_enabled_mini_cart',
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_left_to_free_shipping_settings', array( 'disabled' => 'disabled' ) ),
				'desc_tip' => apply_filters( 'alg_wc_left_to_free_shipping_settings', $this->pro_desc ),
			),
			array(
				'title'    => __( 'Content', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'You can use HTML and/or shortcodes here.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_content_mini_cart',
				'default'  => sprintf( __( '%s left for free shipping', 'amount-left-free-shipping-woocommerce' ), '%amount_left_for_free_shipping%' ),
				'type'     => 'textarea',
				'css'      => 'width:100%;height:100px;',
				'alg_wc_alfs_raw' => true,
			),
			array(
				'title'    => __( 'Position', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_position_mini_cart',
				'default'  => 'woocommerce_after_mini_cart',
				'type'     => 'select',
				'class'    => 'chosen_select',
				'options'  => array(
					'woocommerce_before_mini_cart'                    => __( 'Before mini cart', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_widget_shopping_cart_before_buttons' => __( 'Before buttons', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_after_mini_cart'                     => __( 'After mini cart', 'amount-left-free-shipping-woocommerce' ),
				),
			),
			array(
				'title'    => __( 'Position order (priority)', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'Here you can move the info inside the Position selected above.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_priority_mini_cart',
				'default'  => 10,
				'type'     => 'number',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_left_to_free_shipping_mini_cart_options',
			),

			array(
				'title'    => __( 'Checkout Options', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_left_to_free_shipping_checkout_options',
			),
			array(
				'title'    => __( 'Enable/Disable', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => __( 'Enable section', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_enabled_checkout',
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_left_to_free_shipping_settings', array( 'disabled' => 'disabled' ) ),
				'desc_tip' => apply_filters( 'alg_wc_left_to_free_shipping_settings', $this->pro_desc ),
			),
			array(
				'title'    => __( 'Content', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'You can use HTML and/or shortcodes here.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_content_checkout',
				'default'  => sprintf( __( '%s left for free shipping', 'amount-left-free-shipping-woocommerce' ), '%amount_left_for_free_shipping%' ),
				'type'     => 'textarea',
				'css'      => 'width:100%;height:100px;',
				'alg_wc_alfs_raw' => true,
			),
			array(
				'title'    => __( 'Position', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_position_checkout',
				'default'  => 'woocommerce_checkout_after_order_review',
				'type'     => 'select',
				'class'    => 'chosen_select',
				'options'  => array(
					'woocommerce_before_checkout_form'              => __( 'Before checkout form', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_checkout_before_customer_details'  => __( 'Before customer details', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_checkout_billing'                  => __( 'Billing', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_checkout_shipping'                 => __( 'Shipping', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_checkout_after_customer_details'   => __( 'After customer details', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_checkout_before_order_review'      => __( 'Before order review', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_checkout_order_review'             => __( 'Order review', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_review_order_before_shipping'      => __( 'Order review: Before shipping', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_review_order_after_shipping'       => __( 'Order review: After shipping', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_review_order_before_submit'        => __( 'Order review: Payment: Before submit button', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_review_order_after_submit'         => __( 'Order review: Payment: After submit button', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_checkout_after_order_review'       => __( 'After order review', 'amount-left-free-shipping-woocommerce' ),
					'woocommerce_after_checkout_form'               => __( 'After checkout form', 'amount-left-free-shipping-woocommerce' ),
				),
			),
			array(
				'title'    => __( 'Position order (priority)', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'Here you can move the info inside the Position selected above.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_priority_checkout',
				'default'  => 10,
				'type'     => 'number',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_left_to_free_shipping_checkout_options',
			),

			array(
				'title'    => __( '"Add to Cart" Notice Options', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_left_to_free_shipping_add_to_cart_options',
			),
			array(
				'title'    => __( 'Enable/Disable', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => __( 'Enable section', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_enabled_add_to_cart',
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_left_to_free_shipping_settings', array( 'disabled' => 'disabled' ) ),
				'desc_tip' => apply_filters( 'alg_wc_left_to_free_shipping_settings', $this->pro_desc ),
			),
			array(
				'title'    => __( 'Content', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'You can use HTML and/or shortcodes here.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_content_add_to_cart',
				'default'  => sprintf( __( '%s left for free shipping', 'amount-left-free-shipping-woocommerce' ), '%amount_left_for_free_shipping%' ),
				'type'     => 'textarea',
				'css'      => 'width:100%;height:100px;',
				'alg_wc_alfs_raw' => true,
			),
			array(
				'title'    => __( 'Position', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_position_add_to_cart',
				'default'  => 'after',
				'type'     => 'select',
				'class'    => 'chosen_select',
				'options'  => array(
					'before' => __( 'Before the standard text', 'amount-left-free-shipping-woocommerce' ),
					'after'  => __( 'After the standard text', 'amount-left-free-shipping-woocommerce' ),
				),
			),
			array(
				'title'    => __( 'Glue', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( '"Glue" is inserted between the standard "add to cart" text and "left for free shipping" text.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_glue_add_to_cart',
				'default'  => '<br>',
				'type'     => 'text',
				'alg_wc_alfs_raw' => true,
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_left_to_free_shipping_add_to_cart_options',
			),

			array(
				'title'    => __( '"Free Shipping Reached" Options', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_left_to_free_shipping_reached_options',
			),
			array(
				'title'    => __( 'Message on free shipping reached', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'You can use HTML and/or shortcodes here.', 'amount-left-free-shipping-woocommerce' ) . ' ' .
					__( 'To disable - set it empty.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_content_reached',
				'default'  => __( 'You have free delivery!', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'textarea',
				'css'      => 'width:100%;height:100px;',
				'alg_wc_alfs_raw' => true,
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_left_to_free_shipping_reached_options',
			),
		);

		$user_roles = $this->get_user_roles();
		$advanced_settings = array(
			array(
				'title'    => __( 'Advanced Options', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_left_to_free_shipping_advanced_options',
			),
			array(
				'title'    => __( 'Manual min amount', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'Generally the plugin will retrieve the minimum free shipping order amount automatically, however, if you are using non-standard shipping methods for free shipping, you need to set the amount manually here.', 'amount-left-free-shipping-woocommerce' ) . ' ' .
					__( 'Ignored if set to zero.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_manual_min_amount',
				'default'  => 0,
				'type'     => 'number',
				'custom_attributes' => array( 'min' => 0, 'step' => 0.000001 ),
			),
			array(
				'desc'     => __( 'User roles', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'Select user roles for which you want to set individual manual min amounts.', 'amount-left-free-shipping-woocommerce' ) . ' ' .
					__( 'Save changes for new option fields.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_mma_roles',
				'default'  => array(),
				'type'     => 'multiselect',
				'class'    => 'chosen_select',
				'options'  => $user_roles,
			),
		);
		$min_amount_user_roles = get_option( 'alg_wc_left_to_free_shipping_mma_roles', array() );
		foreach ( $min_amount_user_roles as $user_role ) {
			$advanced_settings = array_merge( $advanced_settings, array(
				array(
					'desc'     => ( isset( $user_roles[ $user_role ] ) ? $user_roles[ $user_role ] : $user_role ),
					'desc_tip' => __( 'Ignored if set to zero.', 'amount-left-free-shipping-woocommerce' ),
					'id'       => "alg_wc_left_to_free_shipping_mma_roles_val[{$user_role}]",
					'default'  => 0,
					'type'     => 'number',
					'custom_attributes' => array( 'min' => 0, 'step' => 0.000001 ),
				),
			) );
		}
		$advanced_settings = array_merge( $advanced_settings, array(
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_left_to_free_shipping_advanced_options',
			),
		) );

		return array_merge( $settings, $advanced_settings );
	}

}

endif;

return new Alg_WC_Left_To_Free_Shipping_Settings_General();
